@@ -7,23 +7,21 @@
 #ifndef UTILS_REMOVE_IF_H
 #define UTILS_REMOVE_IF_H
 
-#include <kactivities-features.h>
 #include <algorithm>
+#include <kactivities-features.h>
 
 /********************************************************************
  *  Syntactic sugar for the erase-remove idiom                      *
  ********************************************************************/
 
-namespace kamd {
-namespace utils {
-
-template <typename Collection, typename Filter>
+namespace kamd
+{
+namespace utils
+{
+template<typename Collection, typename Filter>
 __inline void remove_if(Collection &collection, Filter filter)
 {
-    collection.erase(
-        std::remove_if(
-            collection.begin(), collection.end(), filter),
-        collection.end());
+    collection.erase(std::remove_if(collection.begin(), collection.end(), filter), collection.end());
 }
 
 } // namespace utils
